# Ensys srl
# 
# Questo esempio recupera i dati raw dal sensore di VOC installato nella IndRsp
# 
# Verificare di aver abilitato la porta I2C0, ad esempio integrando nel file
# 	/boot/config.txt 
# le seguenti righe:
# 	#i2c0 - periferiche
# 	dtparam=i2c0=on
# 	dtoverlay=i2c0-bcm2708,pins_28_29
#  
# Per eseguire questo script utilizzare il comando:
# 	python3 ccs811b.py

import smbus
import time
import struct
from gpiozero import LED

i2c0 = smbus.SMBus(0)

HD__DEV__ADDR = 0x5B
HD__ID__ADDR = 0x20
HD__ID__VAL = 0x81

def i2c__byte_read_byte(add):
    i2c0.write_byte(HD__DEV__ADDR, add)
    number = i2c0.read_byte(HD__DEV__ADDR)
    return number

def i2c__byte_read_word(add):
    data_byte = i2c0.read_i2c_block_data(HD__DEV__ADDR, add, 2)
    data_word = data_byte[0]<<8
    data_word |= data_byte[1]
    return data_word

def i2c__byte_read_buffer(add, dim_buffer):
    data_byte = i2c0.read_i2c_block_data(HD__DEV__ADDR, add, dim_buffer)
    return data_byte

def i2c__byte_write(val):
    i2c0.write_byte(HD__DEV__ADDR, val)
    return
    
def i2c__byte_write_byte(add, val):
    data_buffer = [0]
    data_buffer[0] = val
    i2c0.write_i2c_block_data(HD__DEV__ADDR, add, data_buffer)
    return
    
def i2c__byte_write_buffer(add, data):
    i2c0.write_i2c_block_data(HD__DEV__ADDR, add, data)
    return
    
ccs811b_wake = LED(27)

while True:
	ccs811b_wake.off()
	
	# Reset
	buffer_reset = [0x11, 0xE5, 0x72, 0x8A]
	i2c__byte_write_buffer(0xFF, buffer_reset)
	time.sleep(1)
	
	# Lettura ID
	id_chip = i2c__byte_read_byte(HD__ID__ADDR)
	if(id_chip==HD__ID__VAL):
		print("OK, trovato CCS811B!\n")
		
		# Start app
		i2c__byte_write_buffer(0xF4, [])
		time.sleep(.1)
		
		# Data rate
		i2c__byte_write_byte(0x01, 0x10)
		
		while(1):
			status = i2c__byte_read_byte(0x00)
			
			if(status&0x01):
				error = i2c__byte_read_byte(0xE0)
				print("error", error)
			elif(status&0x08):
				buffer_data = i2c__byte_read_buffer(0x02, 8)
				
				print(buffer_data)
			
			time.sleep(1)
		
	else:
	    print(id_chip)

		
	time.sleep(1)

#End of the Script
